Index: src/sans/perspectives/fitting/fitpanel.py
===================================================================
--- src/sans/perspectives/fitting/fitpanel.py	(revision 5777106e8a4a0a62fe2ee0fbaf7c0aa19c0bb92b)
+++ src/sans/perspectives/fitting/fitpanel.py	(revision eddb6eca9b813af3dd1f8c272f767fec8e5252fa)
@@ -384,5 +384,5 @@
         panel._set_save_flag(not panel.batch_on)
         panel.set_model_dictionary(self.model_dictionary)
-        panel.populate_box(dict=self.model_list_box)
+        panel.populate_box(model_dict=self.model_list_box)
         panel.formfactor_combo_init()
         panel.set_manager(self._manager)
Index: src/sans/perspectives/fitting/pagestate.py
===================================================================
--- src/sans/perspectives/fitting/pagestate.py	(revision 44f7c1b491bf7f3fd4a82a4294833b2ec089e0fd)
+++ src/sans/perspectives/fitting/pagestate.py	(revision eddb6eca9b813af3dd1f8c272f767fec8e5252fa)
@@ -17,7 +17,7 @@
 import logging
 import numpy
+import string
 
 import xml.dom.minidom
-from xml.dom.minidom import parse
 from lxml import etree
 
@@ -193,5 +193,5 @@
         ##page name
         self.page_name = ""
-        # Contains link between  model ,all its parameters, and panel organization
+        # Contains link between model, all its parameters, and panel organization
         self.parameters = []
         # String parameter list that can not be fitted
@@ -205,5 +205,5 @@
         ## orientation parameters
         self.orientation_params = []
-        ## orientation parmaters for gaussian dispersity
+        ## orientation parameters for gaussian dispersity
         self.orientation_params_disp = []
         ## smearer info
@@ -216,5 +216,5 @@
         self.dxl = None
         self.dxw = None
-        #list of dispersion paramaters
+        #list of dispersion parameters
         self.disp_list = []
         if self.model is not None:
@@ -600,5 +600,5 @@
         : param figs: list of pylab figures [list]
         """
-        from report_dialog import ReportDialog
+        from sans.perspectives.fitting.report_dialog import ReportDialog
         # get the strings for report
         html_str, text_str, title = self.set_report_string()
@@ -630,9 +630,9 @@
         dialog.ShowModal()
         
-    def _toXML_helper(self, list, element, newdoc):
+    def _toXML_helper(self, thelist, element, newdoc):
         """
         Helper method to create xml file for saving state
         """
-        for item in list:
+        for item in thelist:
             sub_element = newdoc.createElement('parameter')
             sub_element.setAttribute('name', str(item[1]))
Index: src/sans/plottools/PlotPanel.py
===================================================================
--- src/sans/plottools/PlotPanel.py	(revision 8817d07b8cbbaaa27991ce868fc8065499910b47)
+++ src/sans/plottools/PlotPanel.py	(revision eddb6eca9b813af3dd1f8c272f767fec8e5252fa)
@@ -3,4 +3,5 @@
 import logging
 import wx
+import os
 # Try a normal import first
 # If it fails, try specifying a version
@@ -11,16 +12,13 @@
 from matplotlib.backends.backend_wxagg import FigureCanvasWxAgg
 from matplotlib.figure import Figure
-import os
-import transform
-from plottables import Data1D
-#TODO: make the plottables interactive
-from binder import BindArtist
+from sans.plottools import transform
+from sans.plottools.plottables import Data1D
+from sans.plottools.binder import BindArtist
 from matplotlib.font_manager import FontProperties
 DEBUG = False
 
-from plottables import Graph
-from plottables import Text
-from TextDialog import TextDialog
-from LabelDialog import LabelDialog
+from sans.plottools.plottables import Graph
+from sans.plottools.TextDialog import TextDialog
+from sans.plottools.LabelDialog import LabelDialog
 import operator
 
@@ -38,52 +36,51 @@
         for a in obj.get_children(): show_tree(a, d+1)
      
-from unitConverter import UnitConvertion as convertUnit
+from sans.plottools.unitConverter import UnitConvertion as convertUnit
 
 
 def _rescale(lo, hi, step, pt=None, bal=None, scale='linear'):
-        """
-        Rescale (lo,hi) by step, returning the new (lo,hi)
-        The scaling is centered on pt, with positive values of step
-        driving lo/hi away from pt and negative values pulling them in.
-        If bal is given instead of point, it is already in [0,1] coordinates.
+    """
+    Rescale (lo,hi) by step, returning the new (lo,hi)
+    The scaling is centered on pt, with positive values of step
+    driving lo/hi away from pt and negative values pulling them in.
+    If bal is given instead of point, it is already in [0,1] coordinates.
     
-        This is a helper function for step-based zooming.
-        
-        """
-        # Convert values into the correct scale for a linear transformation
-        # TODO: use proper scale transformers
-        loprev = lo
-        hiprev = hi
-        if scale == 'log':
-            assert lo > 0
-            if lo > 0:
-                lo = math.log10(lo)
-            if hi > 0:
-                hi = math.log10(hi)
-            if pt is not None:
-                pt = math.log10(pt)
-        
-        # Compute delta from axis range * %, or 1-% if persent is negative
-        if step > 0:
-            delta = float(hi - lo) * step / 100
+    This is a helper function for step-based zooming.
+    """
+    # Convert values into the correct scale for a linear transformation
+    # TODO: use proper scale transformers
+    loprev = lo
+    hiprev = hi
+    if scale == 'log':
+        assert lo > 0
+        if lo > 0:
+            lo = math.log10(lo)
+        if hi > 0:
+            hi = math.log10(hi)
+        if pt is not None:
+            pt = math.log10(pt)
+    
+    # Compute delta from axis range * %, or 1-% if present is negative
+    if step > 0:
+        delta = float(hi - lo) * step / 100
+    else:
+        delta = float(hi - lo) * step / (100 - step)
+
+    # Add scale factor proportionally to the lo and hi values,
+    # preserving the
+    # point under the mouse
+    if bal is None:
+        bal = float(pt - lo) / (hi - lo)
+    lo = lo - (bal * delta)
+    hi = hi + (1 - bal) * delta
+
+    # Convert transformed values back to the original scale
+    if scale == 'log':
+        if (lo <= -250) or (hi >= 250):
+            lo = loprev
+            hi = hiprev
         else:
-            delta = float(hi - lo) * step / (100 - step)
-    
-        # Add scale factor proportionally to the lo and hi values,
-        # preserving the
-        # point under the mouse
-        if bal is None:
-            bal = float(pt - lo) / (hi - lo)
-        lo = lo - (bal * delta)
-        hi = hi + (1 - bal) * delta
-    
-        # Convert transformed values back to the original scale
-        if scale == 'log':
-            if (lo <= -250) or (hi >= 250):
-                lo = loprev
-                hi = hiprev
-            else:
-                lo, hi = math.pow(10., lo), math.pow(10., hi)
-        return (lo, hi)
+            lo, hi = math.pow(10., lo), math.pow(10., hi)
+    return (lo, hi)
 
 
@@ -125,5 +122,5 @@
         self.figure = Figure(None, dpi, linewidth=2.0)
         self.color = '#b3b3b3'
-        from canvas import FigureCanvas
+        from sans.plottools.canvas import FigureCanvas
         self.canvas = FigureCanvas(self, -1, self.figure)
         self.SetColor(color)
@@ -158,7 +155,7 @@
         
         # Define some constants
-        self.colorlist = ['b','g','r','c','m','y','k']
-        self.symbollist = ['o','x','^','v','<','>','+',
-                           's','d','D','h','H','p', '-']
+        self.colorlist = ['b', 'g', 'r', 'c', 'm', 'y', 'k']
+        self.symbollist = ['o', 'x', '^', 'v', '<', '>', '+',
+                           's', 'd', 'D', 'h', 'H', 'p', '-']
         
         #List of texts currently on the plot

Index: src/sans/perspectives/fitting/basepage.py
===================================================================
--- src/sans/perspectives/fitting/basepage.py	(revision f468791f8ac1d2498ad79b33a2c4a0f06236dec8)
+++ src/sans/perspectives/fitting/basepage.py	(revision eddb6eca9b813af3dd1f8c272f767fec8e5252fa)
@@ -496,5 +496,5 @@
         self.model_list_box = page_info.model_list_box
         ## Data member to store the dispersion object created
-        self.populate_box(dict=self.model_list_box)
+        self.populate_box(model_dict=self.model_list_box)
         
     def onContextMenu(self, event):
@@ -599,12 +599,12 @@
         self.state.manager = manager
         
-    def populate_box(self, dict):
+    def populate_box(self, model_dict):
         """
         Store list of model
         
-        :param dict: dictionary containing list of models
-        
-        """
-        self.model_list_box = dict
+        :param model_dict: dictionary containing list of models
+        
+        """
+        self.model_list_box = model_dict
         self.state.model_list_box = self.model_list_box
         self.initialize_combox()
@@ -928,16 +928,11 @@
                 f_select = self.formfactorbox.GetSelection()
                 if f_select > 0:
-                        self.state.formfactorcombobox = self.formfactorbox.\
-                        GetString(f_select)
+                    self.state.formfactorcombobox = self.formfactorbox.\
+                    GetString(f_select)
         if self.categorybox != None:
-                cb_select = self.categorybox.GetSelection()
-                if cb_select > 0:
-                        self.state.categorycombobox = self.categorybox.\
-                        GetString(cb_select)                
-        #save radiobutton state for model selection
-        #self.state.shape_rbutton = self.shape_rbutton.GetValue()
-        #self.state.shape_indep_rbutton = self.shape_indep_rbutton.GetValue()
-        #self.state.struct_rbutton = self.struct_rbutton.GetValue()
-        #self.state.plugin_rbutton = self.plugin_rbutton.GetValue()
+            cb_select = self.categorybox.GetSelection()
+            if cb_select > 0:
+                self.state.categorycombobox = self.categorybox.\
+                GetString(cb_select)
         
         self.state.enable2D = copy.deepcopy(self.enable2D)
@@ -1045,5 +1040,4 @@
             if len(self.disp_cb_dict) > 0:
                 for k, v in self.disp_cb_dict.iteritems():
-         
                     if v == None:
                         self.state.disp_cb_dict[k] = v
@@ -1053,5 +1047,4 @@
                         except:
                             self.state.disp_cb_dict[k] = None
-           
             if len(self._disp_obj_dict) > 0:
                 for k, v in self._disp_obj_dict.iteritems():